pub struct MetricsLayer<I: MetricsIntercept> { /* private fields */ }Expand description
MetricsLayer reports operation and HTTP metrics to an interceptor.
The layer wraps both the storage service and the HTTP transport in the
operator’s [OperationContext]. It reports the metric names and labels
documented in the crate-level metrics reference through
MetricsIntercept::observe.
The interceptor must be cheap to clone because each wrapped operation and HTTP request can retain a clone.
Implementations
Sourceimpl<I: MetricsIntercept> MetricsLayer<I>
impl<I: MetricsIntercept> MetricsLayer<I>